@@ -21,7 +21,9 @@ __all__ = [
     'Quoted',
 
     # AST types
+    'Async',
     'Await',
+    'ChainedAssignment',
     'CollectionLiteral',
     'ComprehensionExpression',
     'Del',
@@ -29,8 +31,11 @@ __all__ = [
     'ErrorFrom',
     'ExceptionType',
     'ExpressionStatement',
+    'ExpressionTypeTree',
+    'ForLoop',
     'FormattedString',
     'KeyValue',
+    'LiteralType',
     'MatchCase',
     'MultiImport',
     'NamedArgument',
@@ -40,8 +45,10 @@ __all__ = [
     'Star',
     'StatementExpression',
     'TrailingElseWrapper',
+    'TypeAlias',
     'TypeHint',
     'TypeHintedExpression',
+    'UnionType',
     'VariableScope',
     'YieldFrom',
 ]
