@@ -14,6 +14,99 @@ from .support_types import *
 from rewrite import Checksum, FileAttributes, SourceFile, Tree, TreeVisitor, Markers, Cursor, PrintOutputCapture, PrinterFactory
 from rewrite.java import *
 
+# noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
+@dataclass(frozen=True, eq=False)
+class Async(Py, Statement):
+    _id: UUID
+
+    @property
+    def id(self) -> UUID:
+        return self._id
+
+    def with_id(self, id: UUID) -> Async:
+        return self if id is self._id else replace(self, _id=id)
+
+    _prefix: Space
+
+    @property
+    def prefix(self) -> Space:
+        return self._prefix
+
+    def with_prefix(self, prefix: Space) -> Async:
+        return self if prefix is self._prefix else replace(self, _prefix=prefix)
+
+    _markers: Markers
+
+    @property
+    def markers(self) -> Markers:
+        return self._markers
+
+    def with_markers(self, markers: Markers) -> Async:
+        return self if markers is self._markers else replace(self, _markers=markers)
+
+    _statement: Statement
+
+    @property
+    def statement(self) -> Statement:
+        return self._statement
+
+    def with_statement(self, statement: Statement) -> Async:
+        return self if statement is self._statement else replace(self, _statement=statement)
+
+    def accept_python(self, v: PythonVisitor[P], p: P) -> J:
+        return v.visit_async(self, p)
+
+# noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
+@dataclass(frozen=True, eq=False)
+class Await(Py, Expression):
+    _id: UUID
+
+    @property
+    def id(self) -> UUID:
+        return self._id
+
+    def with_id(self, id: UUID) -> Await:
+        return self if id is self._id else replace(self, _id=id)
+
+    _prefix: Space
+
+    @property
+    def prefix(self) -> Space:
+        return self._prefix
+
+    def with_prefix(self, prefix: Space) -> Await:
+        return self if prefix is self._prefix else replace(self, _prefix=prefix)
+
+    _markers: Markers
+
+    @property
+    def markers(self) -> Markers:
+        return self._markers
+
+    def with_markers(self, markers: Markers) -> Await:
+        return self if markers is self._markers else replace(self, _markers=markers)
+
+    _expression: Expression
+
+    @property
+    def expression(self) -> Expression:
+        return self._expression
+
+    def with_expression(self, expression: Expression) -> Await:
+        return self if expression is self._expression else replace(self, _expression=expression)
+
+    _type: JavaType
+
+    @property
+    def type(self) -> JavaType:
+        return self._type
+
+    def with_type(self, type: JavaType) -> Await:
+        return self if type is self._type else replace(self, _type=type)
+
+    def accept_python(self, v: PythonVisitor[P], p: P) -> J:
+        return v.visit_await(self, p)
+
 # noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
 @dataclass(frozen=True, eq=False)
 class Binary(Py, Expression, TypedTree):
@@ -129,6 +222,93 @@ class Binary(Py, Expression, TypedTree):
     def accept_python(self, v: PythonVisitor[P], p: P) -> J:
         return v.visit_python_binary(self, p)
 
+# noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
+@dataclass(frozen=True, eq=False)
+class ChainedAssignment(Py, Statement, TypedTree):
+    _id: UUID
+
+    @property
+    def id(self) -> UUID:
+        return self._id
+
+    def with_id(self, id: UUID) -> ChainedAssignment:
+        return self if id is self._id else replace(self, _id=id)
+
+    _prefix: Space
+
+    @property
+    def prefix(self) -> Space:
+        return self._prefix
+
+    def with_prefix(self, prefix: Space) -> ChainedAssignment:
+        return self if prefix is self._prefix else replace(self, _prefix=prefix)
+
+    _markers: Markers
+
+    @property
+    def markers(self) -> Markers:
+        return self._markers
+
+    def with_markers(self, markers: Markers) -> ChainedAssignment:
+        return self if markers is self._markers else replace(self, _markers=markers)
+
+    _variables: List[JRightPadded[Expression]]
+
+    @property
+    def variables(self) -> List[Expression]:
+        return JRightPadded.get_elements(self._variables)
+
+    def with_variables(self, variables: List[Expression]) -> ChainedAssignment:
+        return self.padding.with_variables(JRightPadded.with_elements(self._variables, variables))
+
+    _assignment: Expression
+
+    @property
+    def assignment(self) -> Expression:
+        return self._assignment
+
+    def with_assignment(self, assignment: Expression) -> ChainedAssignment:
+        return self if assignment is self._assignment else replace(self, _assignment=assignment)
+
+    _type: Optional[JavaType]
+
+    @property
+    def type(self) -> Optional[JavaType]:
+        return self._type
+
+    def with_type(self, type: Optional[JavaType]) -> ChainedAssignment:
+        return self if type is self._type else replace(self, _type=type)
+
+    @dataclass
+    class PaddingHelper:
+        _t: ChainedAssignment
+
+        @property
+        def variables(self) -> List[JRightPadded[Expression]]:
+            return self._t._variables
+
+        def with_variables(self, variables: List[JRightPadded[Expression]]) -> ChainedAssignment:
+            return self._t if self._t._variables is variables else replace(self._t, _variables=variables)
+
+    _padding: weakref.ReferenceType[PaddingHelper] = None
+
+    @property
+    def padding(self) -> PaddingHelper:
+        p: ChainedAssignment.PaddingHelper
+        if self._padding is None:
+            p = ChainedAssignment.PaddingHelper(self)
+            object.__setattr__(self, '_padding', weakref.ref(p))
+        else:
+            p = self._padding()
+            # noinspection PyProtectedMember
+            if p is None or p._t != self:
+                p = ChainedAssignment.PaddingHelper(self)
+                object.__setattr__(self, '_padding', weakref.ref(p))
+        return p
+
+    def accept_python(self, v: PythonVisitor[P], p: P) -> J:
+        return v.visit_chained_assignment(self, p)
+
 # noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
 @dataclass(frozen=True, eq=False)
 class ExceptionType(Py, TypeTree):
@@ -189,6 +369,151 @@ class ExceptionType(Py, TypeTree):
     def accept_python(self, v: PythonVisitor[P], p: P) -> J:
         return v.visit_exception_type(self, p)
 
+# noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
+@dataclass(frozen=True, eq=False)
+class ForLoop(Py, Loop):
+    _id: UUID
+
+    @property
+    def id(self) -> UUID:
+        return self._id
+
+    def with_id(self, id: UUID) -> ForLoop:
+        return self if id is self._id else replace(self, _id=id)
+
+    _prefix: Space
+
+    @property
+    def prefix(self) -> Space:
+        return self._prefix
+
+    def with_prefix(self, prefix: Space) -> ForLoop:
+        return self if prefix is self._prefix else replace(self, _prefix=prefix)
+
+    _markers: Markers
+
+    @property
+    def markers(self) -> Markers:
+        return self._markers
+
+    def with_markers(self, markers: Markers) -> ForLoop:
+        return self if markers is self._markers else replace(self, _markers=markers)
+
+    _target: Expression
+
+    @property
+    def target(self) -> Expression:
+        return self._target
+
+    def with_target(self, target: Expression) -> ForLoop:
+        return self if target is self._target else replace(self, _target=target)
+
+    _iterable: JLeftPadded[Expression]
+
+    @property
+    def iterable(self) -> Expression:
+        return self._iterable.element
+
+    def with_iterable(self, iterable: Expression) -> ForLoop:
+        return self.padding.with_iterable(JLeftPadded.with_element(self._iterable, iterable))
+
+    _body: JRightPadded[Statement]
+
+    @property
+    def body(self) -> Statement:
+        return self._body.element
+
+    def with_body(self, body: Statement) -> ForLoop:
+        return self.padding.with_body(JRightPadded.with_element(self._body, body))
+
+    @dataclass
+    class PaddingHelper:
+        _t: ForLoop
+
+        @property
+        def iterable(self) -> JLeftPadded[Expression]:
+            return self._t._iterable
+
+        def with_iterable(self, iterable: JLeftPadded[Expression]) -> ForLoop:
+            return self._t if self._t._iterable is iterable else replace(self._t, _iterable=iterable)
+
+        @property
+        def body(self) -> JRightPadded[Statement]:
+            return self._t._body
+
+        def with_body(self, body: JRightPadded[Statement]) -> ForLoop:
+            return self._t if self._t._body is body else replace(self._t, _body=body)
+
+    _padding: weakref.ReferenceType[PaddingHelper] = None
+
+    @property
+    def padding(self) -> PaddingHelper:
+        p: ForLoop.PaddingHelper
+        if self._padding is None:
+            p = ForLoop.PaddingHelper(self)
+            object.__setattr__(self, '_padding', weakref.ref(p))
+        else:
+            p = self._padding()
+            # noinspection PyProtectedMember
+            if p is None or p._t != self:
+                p = ForLoop.PaddingHelper(self)
+                object.__setattr__(self, '_padding', weakref.ref(p))
+        return p
+
+    def accept_python(self, v: PythonVisitor[P], p: P) -> J:
+        return v.visit_python_for_loop(self, p)
+
+# noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
+@dataclass(frozen=True, eq=False)
+class LiteralType(Py, Expression, TypeTree):
+    _id: UUID
+
+    @property
+    def id(self) -> UUID:
+        return self._id
+
+    def with_id(self, id: UUID) -> LiteralType:
+        return self if id is self._id else replace(self, _id=id)
+
+    _prefix: Space
+
+    @property
+    def prefix(self) -> Space:
+        return self._prefix
+
+    def with_prefix(self, prefix: Space) -> LiteralType:
+        return self if prefix is self._prefix else replace(self, _prefix=prefix)
+
+    _markers: Markers
+
+    @property
+    def markers(self) -> Markers:
+        return self._markers
+
+    def with_markers(self, markers: Markers) -> LiteralType:
+        return self if markers is self._markers else replace(self, _markers=markers)
+
+    _literal: Expression
+
+    @property
+    def literal(self) -> Expression:
+        return self._literal
+
+    def with_literal(self, literal: Expression) -> LiteralType:
+        return self if literal is self._literal else replace(self, _literal=literal)
+
+    _type: JavaType
+
+    @property
+    def type(self) -> JavaType:
+        return self._type
+
+    def with_type(self, type: JavaType) -> LiteralType:
+        return self if type is self._type else replace(self, _type=type)
+
+    def accept_python(self, v: PythonVisitor[P], p: P) -> J:
+        return v.visit_literal_type(self, p)
+
 # noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
 @dataclass(frozen=True, eq=False)
 class TypeHint(Py, TypeTree):
@@ -406,6 +731,48 @@ class ExpressionStatement(Py, Expression, Statement):
     def accept_python(self, v: PythonVisitor[P], p: P) -> J:
         return v.visit_expression_statement(self, p)
 
+# noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
+@dataclass(frozen=True, eq=False)
+class ExpressionTypeTree(Py, Expression, TypeTree):
+    _id: UUID
+
+    @property
+    def id(self) -> UUID:
+        return self._id
+
+    def with_id(self, id: UUID) -> ExpressionTypeTree:
+        return self if id is self._id else replace(self, _id=id)
+
+    _prefix: Space
+
+    @property
+    def prefix(self) -> Space:
+        return self._prefix
+
+    def with_prefix(self, prefix: Space) -> ExpressionTypeTree:
+        return self if prefix is self._prefix else replace(self, _prefix=prefix)
+
+    _markers: Markers
+
+    @property
+    def markers(self) -> Markers:
+        return self._markers
+
+    def with_markers(self, markers: Markers) -> ExpressionTypeTree:
+        return self if markers is self._markers else replace(self, _markers=markers)
+
+    _reference: J
+
+    @property
+    def reference(self) -> J:
+        return self._reference
+
+    def with_reference(self, reference: J) -> ExpressionTypeTree:
+        return self if reference is self._reference else replace(self, _reference=reference)
+
+    def accept_python(self, v: PythonVisitor[P], p: P) -> J:
+        return v.visit_expression_type_tree(self, p)
+
 # noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
 @dataclass(frozen=True, eq=False)
 class StatementExpression(Py, Expression, Statement):
@@ -418,6 +785,13 @@ class StatementExpression(Py, Expression, Statement):
     def with_id(self, id: UUID) -> StatementExpression:
         return self if id is self._id else replace(self, _id=id)
 
+    @property
+    def prefix(self) -> Space:
+        return self._statement.prefix
+
+    def with_prefix(self, prefix: Space) -> StatementExpression:
+        return self._statement.with_prefix(prefix)
+
     _statement: Statement
 
     @property
@@ -1204,6 +1578,15 @@ class ComprehensionExpression(Py, Expression):
         def with_markers(self, markers: Markers) -> ComprehensionExpression.Clause:
             return self if markers is self._markers else replace(self, _markers=markers)
 
+        _async: Optional[JRightPadded[bool]]
+
+        @property
+        def async_(self) -> Optional[bool]:
+            return self._async.element
+
+        def with_async(self, async_: Optional[bool]) -> ComprehensionExpression.Clause:
+            return self.padding.with_async(JRightPadded.with_element(self._async, async_))
+
         _iterator_variable: Expression
 
         @property
@@ -1235,6 +1618,13 @@ class ComprehensionExpression(Py, Expression):
         class PaddingHelper:
             _t: ComprehensionExpression.Clause
 
+            @property
+            def async_(self) -> Optional[JRightPadded[bool]]:
+                return self._t._async
+
+            def with_async(self, async_: Optional[JRightPadded[bool]]) -> ComprehensionExpression.Clause:
+                return self._t if self._t._async is async_ else replace(self._t, _async=async_)
+
             @property
             def iterated_list(self) -> JLeftPadded[Expression]:
                 return self._t._iterated_list
@@ -1266,14 +1656,14 @@ class ComprehensionExpression(Py, Expression):
 
 # noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
 @dataclass(frozen=True, eq=False)
-class Await(Py, Expression):
+class TypeAlias(Py, Statement, TypedTree):
     _id: UUID
 
     @property
     def id(self) -> UUID:
         return self._id
 
-    def with_id(self, id: UUID) -> Await:
+    def with_id(self, id: UUID) -> TypeAlias:
         return self if id is self._id else replace(self, _id=id)
 
     _prefix: Space
@@ -1282,7 +1672,7 @@ class Await(Py, Expression):
     def prefix(self) -> Space:
         return self._prefix
 
-    def with_prefix(self, prefix: Space) -> Await:
+    def with_prefix(self, prefix: Space) -> TypeAlias:
         return self if prefix is self._prefix else replace(self, _prefix=prefix)
 
     _markers: Markers
@@ -1291,29 +1681,65 @@ class Await(Py, Expression):
     def markers(self) -> Markers:
         return self._markers
 
-    def with_markers(self, markers: Markers) -> Await:
+    def with_markers(self, markers: Markers) -> TypeAlias:
         return self if markers is self._markers else replace(self, _markers=markers)
 
-    _expression: Expression
+    _name: Identifier
 
     @property
-    def expression(self) -> Expression:
-        return self._expression
+    def name(self) -> Identifier:
+        return self._name
 
-    def with_expression(self, expression: Expression) -> Await:
-        return self if expression is self._expression else replace(self, _expression=expression)
+    def with_name(self, name: Identifier) -> TypeAlias:
+        return self if name is self._name else replace(self, _name=name)
 
-    _type: JavaType
+    _value: JLeftPadded[J]
 
     @property
-    def type(self) -> JavaType:
+    def value(self) -> J:
+        return self._value.element
+
+    def with_value(self, value: J) -> TypeAlias:
+        return self.padding.with_value(JLeftPadded.with_element(self._value, value))
+
+    _type: Optional[JavaType]
+
+    @property
+    def type(self) -> Optional[JavaType]:
         return self._type
 
-    def with_type(self, type: JavaType) -> Await:
+    def with_type(self, type: Optional[JavaType]) -> TypeAlias:
         return self if type is self._type else replace(self, _type=type)
 
+    @dataclass
+    class PaddingHelper:
+        _t: TypeAlias
+
+        @property
+        def value(self) -> JLeftPadded[J]:
+            return self._t._value
+
+        def with_value(self, value: JLeftPadded[J]) -> TypeAlias:
+            return self._t if self._t._value is value else replace(self._t, _value=value)
+
+    _padding: weakref.ReferenceType[PaddingHelper] = None
+
+    @property
+    def padding(self) -> PaddingHelper:
+        p: TypeAlias.PaddingHelper
+        if self._padding is None:
+            p = TypeAlias.PaddingHelper(self)
+            object.__setattr__(self, '_padding', weakref.ref(p))
+        else:
+            p = self._padding()
+            # noinspection PyProtectedMember
+            if p is None or p._t != self:
+                p = TypeAlias.PaddingHelper(self)
+                object.__setattr__(self, '_padding', weakref.ref(p))
+        return p
+
     def accept_python(self, v: PythonVisitor[P], p: P) -> J:
-        return v.visit_await(self, p)
+        return v.visit_type_alias(self, p)
 
 # noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
 @dataclass(frozen=True, eq=False)
@@ -1366,6 +1792,84 @@ class YieldFrom(Py, Expression):
     def accept_python(self, v: PythonVisitor[P], p: P) -> J:
         return v.visit_yield_from(self, p)
 
+# noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
+@dataclass(frozen=True, eq=False)
+class UnionType(Py, Expression, TypeTree):
+    _id: UUID
+
+    @property
+    def id(self) -> UUID:
+        return self._id
+
+    def with_id(self, id: UUID) -> UnionType:
+        return self if id is self._id else replace(self, _id=id)
+
+    _prefix: Space
+
+    @property
+    def prefix(self) -> Space:
+        return self._prefix
+
+    def with_prefix(self, prefix: Space) -> UnionType:
+        return self if prefix is self._prefix else replace(self, _prefix=prefix)
+
+    _markers: Markers
+
+    @property
+    def markers(self) -> Markers:
+        return self._markers
+
+    def with_markers(self, markers: Markers) -> UnionType:
+        return self if markers is self._markers else replace(self, _markers=markers)
+
+    _types: List[JRightPadded[Expression]]
+
+    @property
+    def types(self) -> List[Expression]:
+        return JRightPadded.get_elements(self._types)
+
+    def with_types(self, types: List[Expression]) -> UnionType:
+        return self.padding.with_types(JRightPadded.with_elements(self._types, types))
+
+    _type: Optional[JavaType]
+
+    @property
+    def type(self) -> Optional[JavaType]:
+        return self._type
+
+    def with_type(self, type: Optional[JavaType]) -> UnionType:
+        return self if type is self._type else replace(self, _type=type)
+
+    @dataclass
+    class PaddingHelper:
+        _t: UnionType
+
+        @property
+        def types(self) -> List[JRightPadded[Expression]]:
+            return self._t._types
+
+        def with_types(self, types: List[JRightPadded[Expression]]) -> UnionType:
+            return self._t if self._t._types is types else replace(self._t, _types=types)
+
+    _padding: weakref.ReferenceType[PaddingHelper] = None
+
+    @property
+    def padding(self) -> PaddingHelper:
+        p: UnionType.PaddingHelper
+        if self._padding is None:
+            p = UnionType.PaddingHelper(self)
+            object.__setattr__(self, '_padding', weakref.ref(p))
+        else:
+            p = self._padding()
+            # noinspection PyProtectedMember
+            if p is None or p._t != self:
+                p = UnionType.PaddingHelper(self)
+                object.__setattr__(self, '_padding', weakref.ref(p))
+        return p
+
+    def accept_python(self, v: PythonVisitor[P], p: P) -> J:
+        return v.visit_union_type(self, p)
+
 # noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
 @dataclass(frozen=True, eq=False)
 class VariableScope(Py, Statement):
@@ -1583,7 +2087,7 @@ class SpecialParameter(Py, TypeTree):
 
 # noinspection PyShadowingBuiltins,PyShadowingNames,DuplicatedCode
 @dataclass(frozen=True, eq=False)
-class Star(Py, Expression):
+class Star(Py, Expression, TypeTree):
     class Kind(Enum):
         LIST = 0
         DICT = 1
@@ -1762,15 +2266,6 @@ class TypeHintedExpression(Py, Expression):
     def with_markers(self, markers: Markers) -> TypeHintedExpression:
         return self if markers is self._markers else replace(self, _markers=markers)
 
-    _type_hint: TypeHint
-
-    @property
-    def type_hint(self) -> TypeHint:
-        return self._type_hint
-
-    def with_type_hint(self, type_hint: TypeHint) -> TypeHintedExpression:
-        return self if type_hint is self._type_hint else replace(self, _type_hint=type_hint)
-
     _expression: Expression
 
     @property
@@ -1780,6 +2275,15 @@ class TypeHintedExpression(Py, Expression):
     def with_expression(self, expression: Expression) -> TypeHintedExpression:
         return self if expression is self._expression else replace(self, _expression=expression)
 
+    _type_hint: TypeHint
+
+    @property
+    def type_hint(self) -> TypeHint:
+        return self._type_hint
+
+    def with_type_hint(self, type_hint: TypeHint) -> TypeHintedExpression:
+        return self if type_hint is self._type_hint else replace(self, _type_hint=type_hint)
+
     _type: Optional[JavaType]
 
     @property
