@@ -11,6 +11,26 @@ class PythonVisitor(JavaVisitor[P]):
     def is_acceptable(self, source_file: SourceFile, p: P) -> bool:
         return isinstance(source_file, Py)
 
+    def visit_async(self, async_: Async, p: P) -> J:
+        async_ = async_.with_prefix(self.visit_space(async_.prefix, PySpace.Location.ASYNC_PREFIX, p))
+        temp_statement = cast(Statement, self.visit_statement(async_, p))
+        if not isinstance(temp_statement, Async):
+            return temp_statement
+        async_ = cast(Async, temp_statement)
+        async_ = async_.with_markers(self.visit_markers(async_.markers, p))
+        async_ = async_.with_statement(self.visit_and_cast(async_.statement, Statement, p))
+        return async_
+
+    def visit_await(self, await_: Await, p: P) -> J:
+        await_ = await_.with_prefix(self.visit_space(await_.prefix, PySpace.Location.AWAIT_PREFIX, p))
+        temp_expression = cast(Expression, self.visit_expression(await_, p))
+        if not isinstance(temp_expression, Await):
+            return temp_expression
+        await_ = cast(Await, temp_expression)
+        await_ = await_.with_markers(self.visit_markers(await_.markers, p))
+        await_ = await_.with_expression(self.visit_and_cast(await_.expression, Expression, p))
+        return await_
+
     def visit_python_binary(self, binary: Binary, p: P) -> J:
         binary = binary.with_prefix(self.visit_space(binary.prefix, PySpace.Location.BINARY_PREFIX, p))
         temp_expression = cast(Expression, self.visit_expression(binary, p))
@@ -24,12 +44,45 @@ class PythonVisitor(JavaVisitor[P]):
         binary = binary.with_right(self.visit_and_cast(binary.right, Expression, p))
         return binary
 
+    def visit_chained_assignment(self, chained_assignment: ChainedAssignment, p: P) -> J:
+        chained_assignment = chained_assignment.with_prefix(self.visit_space(chained_assignment.prefix, PySpace.Location.CHAINED_ASSIGNMENT_PREFIX, p))
+        temp_statement = cast(Statement, self.visit_statement(chained_assignment, p))
+        if not isinstance(temp_statement, ChainedAssignment):
+            return temp_statement
+        chained_assignment = cast(ChainedAssignment, temp_statement)
+        chained_assignment = chained_assignment.with_markers(self.visit_markers(chained_assignment.markers, p))
+        chained_assignment = chained_assignment.padding.with_variables([self.visit_right_padded(v, PyRightPadded.Location.CHAINED_ASSIGNMENT_VARIABLES, p) for v in chained_assignment.padding.variables])
+        chained_assignment = chained_assignment.with_assignment(self.visit_and_cast(chained_assignment.assignment, Expression, p))
+        return chained_assignment
+
     def visit_exception_type(self, exception_type: ExceptionType, p: P) -> J:
         exception_type = exception_type.with_prefix(self.visit_space(exception_type.prefix, PySpace.Location.EXCEPTION_TYPE_PREFIX, p))
         exception_type = exception_type.with_markers(self.visit_markers(exception_type.markers, p))
         exception_type = exception_type.with_expression(self.visit_and_cast(exception_type.expression, Expression, p))
         return exception_type
 
+    def visit_python_for_loop(self, for_loop: ForLoop, p: P) -> J:
+        for_loop = for_loop.with_prefix(self.visit_space(for_loop.prefix, PySpace.Location.FOR_LOOP_PREFIX, p))
+        temp_statement = cast(Statement, self.visit_statement(for_loop, p))
+        if not isinstance(temp_statement, ForLoop):
+            return temp_statement
+        for_loop = cast(ForLoop, temp_statement)
+        for_loop = for_loop.with_markers(self.visit_markers(for_loop.markers, p))
+        for_loop = for_loop.with_target(self.visit_and_cast(for_loop.target, Expression, p))
+        for_loop = for_loop.padding.with_iterable(self.visit_left_padded(for_loop.padding.iterable, PyLeftPadded.Location.FOR_LOOP_ITERABLE, p))
+        for_loop = for_loop.padding.with_body(self.visit_right_padded(for_loop.padding.body, PyRightPadded.Location.FOR_LOOP_BODY, p))
+        return for_loop
+
+    def visit_literal_type(self, literal_type: LiteralType, p: P) -> J:
+        literal_type = literal_type.with_prefix(self.visit_space(literal_type.prefix, PySpace.Location.LITERAL_TYPE_PREFIX, p))
+        temp_expression = cast(Expression, self.visit_expression(literal_type, p))
+        if not isinstance(temp_expression, LiteralType):
+            return temp_expression
+        literal_type = cast(LiteralType, temp_expression)
+        literal_type = literal_type.with_markers(self.visit_markers(literal_type.markers, p))
+        literal_type = literal_type.with_literal(self.visit_and_cast(literal_type.literal, Expression, p))
+        return literal_type
+
     def visit_type_hint(self, type_hint: TypeHint, p: P) -> J:
         type_hint = type_hint.with_prefix(self.visit_space(type_hint.prefix, PySpace.Location.TYPE_HINT_PREFIX, p))
         type_hint = type_hint.with_markers(self.visit_markers(type_hint.markers, p))
@@ -48,6 +101,16 @@ class PythonVisitor(JavaVisitor[P]):
         expression_statement = expression_statement.with_expression(self.visit_and_cast(expression_statement.expression, Expression, p))
         return expression_statement
 
+    def visit_expression_type_tree(self, expression_type_tree: ExpressionTypeTree, p: P) -> J:
+        expression_type_tree = expression_type_tree.with_prefix(self.visit_space(expression_type_tree.prefix, PySpace.Location.EXPRESSION_TYPE_TREE_PREFIX, p))
+        temp_expression = cast(Expression, self.visit_expression(expression_type_tree, p))
+        if not isinstance(temp_expression, ExpressionTypeTree):
+            return temp_expression
+        expression_type_tree = cast(ExpressionTypeTree, temp_expression)
+        expression_type_tree = expression_type_tree.with_markers(self.visit_markers(expression_type_tree.markers, p))
+        expression_type_tree = expression_type_tree.with_reference(self.visit_and_cast(expression_type_tree.reference, J, p))
+        return expression_type_tree
+
     def visit_statement_expression(self, statement_expression: StatementExpression, p: P) -> J:
         statement_expression = statement_expression.with_statement(self.visit_and_cast(statement_expression.statement, Statement, p))
         return statement_expression
@@ -157,20 +220,22 @@ class PythonVisitor(JavaVisitor[P]):
     def visit_comprehension_clause(self, clause: ComprehensionExpression.Clause, p: P) -> J:
         clause = clause.with_prefix(self.visit_space(clause.prefix, PySpace.Location.COMPREHENSION_EXPRESSION_CLAUSE_PREFIX, p))
         clause = clause.with_markers(self.visit_markers(clause.markers, p))
+        clause = clause.padding.with_async(self.visit_right_padded(clause.padding.async_, PyRightPadded.Location.COMPREHENSION_EXPRESSION_CLAUSE_ASYNC, p))
         clause = clause.with_iterator_variable(self.visit_and_cast(clause.iterator_variable, Expression, p))
         clause = clause.padding.with_iterated_list(self.visit_left_padded(clause.padding.iterated_list, PyLeftPadded.Location.COMPREHENSION_EXPRESSION_CLAUSE_ITERATED_LIST, p))
         clause = clause.with_conditions([self.visit_and_cast(v, ComprehensionExpression.Condition, p) for v in clause.conditions])
         return clause
 
-    def visit_await(self, await_: Await, p: P) -> J:
-        await_ = await_.with_prefix(self.visit_space(await_.prefix, PySpace.Location.AWAIT_PREFIX, p))
-        temp_expression = cast(Expression, self.visit_expression(await_, p))
-        if not isinstance(temp_expression, Await):
-            return temp_expression
-        await_ = cast(Await, temp_expression)
-        await_ = await_.with_markers(self.visit_markers(await_.markers, p))
-        await_ = await_.with_expression(self.visit_and_cast(await_.expression, Expression, p))
-        return await_
+    def visit_type_alias(self, type_alias: TypeAlias, p: P) -> J:
+        type_alias = type_alias.with_prefix(self.visit_space(type_alias.prefix, PySpace.Location.TYPE_ALIAS_PREFIX, p))
+        temp_statement = cast(Statement, self.visit_statement(type_alias, p))
+        if not isinstance(temp_statement, TypeAlias):
+            return temp_statement
+        type_alias = cast(TypeAlias, temp_statement)
+        type_alias = type_alias.with_markers(self.visit_markers(type_alias.markers, p))
+        type_alias = type_alias.with_name(self.visit_and_cast(type_alias.name, Identifier, p))
+        type_alias = type_alias.padding.with_value(self.visit_left_padded(type_alias.padding.value, PyLeftPadded.Location.TYPE_ALIAS_VALUE, p))
+        return type_alias
 
     def visit_yield_from(self, yield_from: YieldFrom, p: P) -> J:
         yield_from = yield_from.with_prefix(self.visit_space(yield_from.prefix, PySpace.Location.YIELD_FROM_PREFIX, p))
@@ -182,6 +247,16 @@ class PythonVisitor(JavaVisitor[P]):
         yield_from = yield_from.with_expression(self.visit_and_cast(yield_from.expression, Expression, p))
         return yield_from
 
+    def visit_union_type(self, union_type: UnionType, p: P) -> J:
+        union_type = union_type.with_prefix(self.visit_space(union_type.prefix, PySpace.Location.UNION_TYPE_PREFIX, p))
+        temp_expression = cast(Expression, self.visit_expression(union_type, p))
+        if not isinstance(temp_expression, UnionType):
+            return temp_expression
+        union_type = cast(UnionType, temp_expression)
+        union_type = union_type.with_markers(self.visit_markers(union_type.markers, p))
+        union_type = union_type.padding.with_types([self.visit_right_padded(v, PyRightPadded.Location.UNION_TYPE_TYPES, p) for v in union_type.padding.types])
+        return union_type
+
     def visit_variable_scope(self, variable_scope: VariableScope, p: P) -> J:
         variable_scope = variable_scope.with_prefix(self.visit_space(variable_scope.prefix, PySpace.Location.VARIABLE_SCOPE_PREFIX, p))
         temp_statement = cast(Statement, self.visit_statement(variable_scope, p))
@@ -236,8 +311,8 @@ class PythonVisitor(JavaVisitor[P]):
             return temp_expression
         type_hinted_expression = cast(TypeHintedExpression, temp_expression)
         type_hinted_expression = type_hinted_expression.with_markers(self.visit_markers(type_hinted_expression.markers, p))
-        type_hinted_expression = type_hinted_expression.with_type_hint(self.visit_and_cast(type_hinted_expression.type_hint, TypeHint, p))
         type_hinted_expression = type_hinted_expression.with_expression(self.visit_and_cast(type_hinted_expression.expression, Expression, p))
+        type_hinted_expression = type_hinted_expression.with_type_hint(self.visit_and_cast(type_hinted_expression.type_hint, TypeHint, p))
         return type_hinted_expression
 
     def visit_error_from(self, error_from: ErrorFrom, p: P) -> J:
